=== modified file 'client/drizzledump_mysql.cc'
--- client/drizzledump_mysql.cc	2011-03-10 22:48:22 +0000
+++ client/drizzledump_mysql.cc	2011-07-05 18:15:41 +0000
@@ -382,7 +382,7 @@
     old_type.erase(pos, std::string::npos);
   }
 
-  std::transform(old_type.begin(), old_type.end(), old_type.begin(), ::toupper);
+  boost::to_upper(old_type);
   if ((old_type.find("CHAR") != std::string::npos) or 
     (old_type.find("TEXT") != std::string::npos))
     setCollate(raw_collation);

=== modified file 'drizzled/definition/cache.cc'
--- drizzled/definition/cache.cc	2011-06-23 11:44:30 +0000
+++ drizzled/definition/cache.cc	2011-07-05 18:15:41 +0000
@@ -65,10 +65,7 @@
 
   vector.reserve(definition::Cache::size());
 
-  std::transform(cache.begin(),
-                 cache.end(),
-                 std::back_inserter(vector),
-                 boost::bind(&Map::value_type::second, _1) );
+  std::transform(cache.begin(), cache.end(), std::back_inserter(vector), boost::bind(&Map::value_type::second, _1));
   assert(vector.size() == cache.size());
 }
 

=== modified file 'drizzled/plugin/xa_resource_manager.cc'
--- drizzled/plugin/xa_resource_manager.cc	2011-06-24 15:25:06 +0000
+++ drizzled/plugin/xa_resource_manager.cc	2011-07-05 18:15:41 +0000
@@ -39,23 +39,15 @@
 namespace drizzled {
 namespace plugin {
 
-static std::vector<XaResourceManager *> xa_resource_managers;
+typedef std::vector<XaResourceManager*> xa_resource_managers_t;
+static xa_resource_managers_t xa_resource_managers;
 
 int XaResourceManager::commitOrRollbackXID(XID *xid, bool commit)
 {
   std::vector<int> results;
-
-  if (commit)
-    transform(xa_resource_managers.begin(), xa_resource_managers.end(), results.begin(),
-              std::bind2nd(std::mem_fun(&XaResourceManager::xaCommitXid), xid));
-  else
-    transform(xa_resource_managers.begin(), xa_resource_managers.end(), results.begin(),
-              std::bind2nd(std::mem_fun(&XaResourceManager::xaRollbackXid), xid));
-
-  if (std::find_if(results.begin(), results.end(), std::bind2nd(std::equal_to<int>(),0)) == results.end())
-    return 1;
-
-  return 0;
+  BOOST_FOREACH(XaResourceManager* it, xa_resource_managers)
+    results.push_back(commit ? it->xaCommitXid(xid) : it->xaRollbackXid(xid));
+  return std::find(results.begin(), results.end(), 0) == results.end();
 }
 
 /**

=== modified file 'drizzled/table/instance/base.h'
--- drizzled/table/instance/base.h	2011-07-05 15:22:15 +0000
+++ drizzled/table/instance/base.h	2011-07-05 18:15:41 +0000
@@ -187,11 +187,9 @@
 
   std::vector<std::string> _keynames;
 
-  void addKeyName(std::string arg)
+  void addKeyName(const std::string& arg)
   {
-    std::transform(arg.begin(), arg.end(),
-                   arg.begin(), ::toupper);
-    _keynames.push_back(arg);
+    _keynames.push_back(boost::to_upper_copy(arg));
   }
 
 public:
@@ -200,12 +198,9 @@
     return doesKeyNameExist(std::string(name_arg, name_length), position);
   }
 
-  bool doesKeyNameExist(std::string arg, uint32_t &position) const
+  bool doesKeyNameExist(const std::string& arg, uint32_t &position) const
   {
-    std::transform(arg.begin(), arg.end(),
-                   arg.begin(), ::toupper);
-
-    std::vector<std::string>::const_iterator iter= std::find(_keynames.begin(), _keynames.end(), arg);
+    std::vector<std::string>::const_iterator iter= std::find(_keynames.begin(), _keynames.end(), boost::to_upper_copy(arg));
 
     if (iter == _keynames.end())
     {
@@ -214,7 +209,6 @@
     }
 
     position= iter -  _keynames.begin();
-
     return true;
   }
 

=== modified file 'drizzled/table_list.cc'
--- drizzled/table_list.cc	2011-07-05 13:16:34 +0000
+++ drizzled/table_list.cc	2011-07-05 18:15:41 +0000
@@ -156,14 +156,12 @@
     key_map index_join[INDEX_HINT_FORCE + 1];
     key_map index_order[INDEX_HINT_FORCE + 1];
     key_map index_group[INDEX_HINT_FORCE + 1];
-    Index_hint *hint;
-    int type;
     bool have_empty_use_join= false, have_empty_use_order= false,
          have_empty_use_group= false;
     List_iterator <Index_hint> iter(index_hints->begin());
 
     /* initialize temporary variables used to collect hints of each kind */
-    for (type= INDEX_HINT_IGNORE; type <= INDEX_HINT_FORCE; type++)
+    for (int type= INDEX_HINT_IGNORE; type <= INDEX_HINT_FORCE; type++)
     {
       index_join[type].reset();
       index_order[type].reset();
@@ -171,10 +169,8 @@
     }
 
     /* iterate over the hints list */
-    while ((hint= iter++))
+    while (Index_hint* hint= iter++)
     {
-      uint32_t pos= 0;
-
       /* process empty USE INDEX () */
       if (hint->type == INDEX_HINT_USE && !hint->key_name.str)
       {
@@ -200,6 +196,7 @@
         Check if an index with the given name exists and get his offset in
         the keys bitmask for the table
       */
+      uint32_t pos= 0;
       if (not tbl->getShare()->doesKeyNameExist(hint->key_name.str, hint->key_name.length, pos))
       {
         my_error(ER_KEY_DOES_NOT_EXITS, MYF(0), hint->key_name.str, alias);

=== modified file 'drizzled/util/data_ref.h'
--- drizzled/util/data_ref.h	2011-07-05 13:16:34 +0000
+++ drizzled/util/data_ref.h	2011-07-05 18:15:41 +0000
@@ -60,14 +60,14 @@
 
   void assign(const void* b, const void* e)
   {
-		begin_ = reinterpret_cast<T>(b);
-		end_ = reinterpret_cast<T>(e);
+    begin_ = reinterpret_cast<T>(b);
+    end_ = reinterpret_cast<T>(e);
   }
 
   void assign(const void* b, size_t sz)
   {
-		begin_ = reinterpret_cast<T>(b);
-		end_ = begin_ + sz;
+    begin_ = reinterpret_cast<T>(b);
+    end_ = begin_ + sz;
   }
 
   T begin() const

=== modified file 'plugin/filtered_replicator/filtered_replicator.cc'
--- plugin/filtered_replicator/filtered_replicator.cc	2011-07-05 12:15:12 +0000
+++ plugin/filtered_replicator/filtered_replicator.cc	2011-07-05 18:15:41 +0000
@@ -302,8 +302,7 @@
    * Convert the input string to lowercase so that all entries in the vector
    * will be in lowercase.
    */
-  std::transform(input.begin(), input.end(),
-                 input.begin(), ::tolower);
+  boost::to_lower(input);
   string::size_type last_pos= input.find_first_not_of(',', 0);
   string::size_type pos= input.find_first_of(',', last_pos);
 
@@ -382,8 +381,7 @@
    * Convert the type string to uppercase here so that it doesn't
    * matter what case the user entered the statement in.
    */
-  std::transform(type.begin(), type.end(),
-                 type.begin(), ::toupper);
+  boost::to_upper(type);
 
   if (type.compare("DROP") == 0)
   {

=== modified file 'plugin/haildb/haildb_engine.cc'
--- plugin/haildb/haildb_engine.cc	2011-07-05 12:15:12 +0000
+++ plugin/haildb/haildb_engine.cc	2011-07-05 18:15:41 +0000
@@ -786,11 +786,9 @@
 
   if (strncmp(name, sys_prefix.c_str(), sys_prefix.length()) == 0)
   {
-    string find_name(name+datadict_path.length());
-    std::transform(find_name.begin(), find_name.end(), find_name.begin(), ::toupper);
-    boost::unordered_set<string>::iterator iter= haildb_system_table_names.find(find_name);
+    boost::unordered_set<string>::iterator iter= haildb_system_table_names.find(boost::to_upper_copy(string(name + datadict_path.length())));
     if (iter != haildb_system_table_names.end())
-      return iter->c_str()+sys_table_prefix.length();
+      return iter->c_str() + sys_table_prefix.length();
   }
 
   int slashes= 2;

=== modified file 'plugin/memcached_functions/memc_behavior_get.cc'
--- plugin/memcached_functions/memc_behavior_get.cc	2011-02-17 00:14:13 +0000
+++ plugin/memcached_functions/memc_behavior_get.cc	2011-07-05 18:15:41 +0000
@@ -54,9 +54,6 @@
 
 String *MemcachedBehaviorGet::val_str(String *str)
 {
-  memcached_behavior mbehavior;
-  uint64_t isetting;
-  map<const string, memcached_behavior>::iterator it;
   String *tmp_behavior;
 
   if (arg_count != 1 ||
@@ -67,25 +64,21 @@
     return &failure_buff;
   }
 
-  string behavior(tmp_behavior->c_ptr());
-
   /*
    * We don't want the user to have to type in all input in upper
    * case so we transform the input strings to upper case here.
    */
-  std::transform(behavior.begin(), behavior.end(),
-                 behavior.begin(), ::toupper);
 
-  it = behavior_map.find(behavior);
-  if (it == behavior_map.end()) 
+  memcached_behavior* it = find_ptr(behavior_map, boost::to_upper_copy(string(tmp_behavior->c_ptr())));
+  if (not it) 
   {
     setFailureString("UNKNOWN BEHAVIOR TYPE!");
     return &failure_buff;
   }
 	
-  mbehavior= behavior_map[behavior];
+  memcached_behavior mbehavior= *it;
 
-  isetting= memcached_behavior_get(memc, mbehavior);
+  uint64_t isetting= memcached_behavior_get(memc, mbehavior);
 
   switch (mbehavior)
   {

=== modified file 'plugin/memcached_functions/memc_behavior_set.cc'
--- plugin/memcached_functions/memc_behavior_set.cc	2011-02-17 00:14:13 +0000
+++ plugin/memcached_functions/memc_behavior_set.cc	2011-07-05 18:15:41 +0000
@@ -79,10 +79,8 @@
    * We don't want the user to have to type in all input in upper
    * case so we transform the input strings to upper case here.
    */
-  std::transform(behavior.begin(), behavior.end(),
-                 behavior.begin(), ::toupper);
-  std::transform(setting.begin(), setting.end(),
-                 setting.begin(), ::toupper);
+  boost::to_upper(behavior);
+  boost::to_upper(setting);
 
   it_behav= behavior_map.find(behavior);
   if (it_behav == behavior_map.end())

